function [labels]=m_gen_mol_coord(varargin)
% The input of this function is a structure containing parameters for the
% actual pattern. It reads the coordinates of the actual pattern's
% structure, then calculates the positions of the contact points and dye
% molecules and the orientation of dye molecules. The output structure
% contains these mentioned values.

% PARENT: m_gen_calc_dye_coords.m
% CHILDS:   m_gen_mol_coord_lattice
%           m_gen_mol_coord_tubules
%           m_gen_mol_coord_segments
%           m_gen_mol_coord_octagons
%           m_gen_mol_coord_vesicles
%           m_gen_mol_coord_rods
%           m_gen_mol_coord_axons
%           m_gen_mol_coord_disks
%           m_gen_mol_coord_mesh

switch length(varargin)
    case 1
        params = varargin{1};   % struct containing the actual pattern's parameters
    otherwise
        error('Invalid input.')
end

name=params.sample.name;       % name of the actual pattern

if ~ischar(name)
    error('Invalid input.')
end

switch name
    case 'star'
        mesh_coords=params.struct_coords;
        [labels] = m_gen_mol_coord_mesh(mesh_coords, params);
    case 'lattice'
        point_coords=params.struct_coords;
        %[labels] = m_gen_mol_coord_lattice(point_coords, params);
        [labels] = m_gen_mol_coord_points(point_coords, params);
    case 'lines'
        vert_coords=params.struct_coords;
        [labels] = m_gen_mol_coord_tubules(vert_coords, params);
    case 'octagons'
        %vert_coords=params.struct_coords;
        %[labels] = m_gen_mol_coord_octagons(vert_coords, params);
        point_coords=params.struct_coords;
        [labels] = m_gen_mol_coord_points(point_coords, params);
    case 'vesicles'
        vesicle_coords=params.struct_coords;
        [labels] = m_gen_mol_coord_vesicles(vesicle_coords, params);
    case 'rods'
        rod_coords=params.struct_coords;
        [labels] = m_gen_mol_coord_rods(rod_coords, params);
    case 'axons'
        vert_coords=params.struct_coords;
        [labels] = m_gen_mol_coord_axons(vert_coords, params);
    case 'disks'
        vert_coords=params.struct_coords;
        [labels] = m_gen_mol_coord_disks(vert_coords, params);
    case 'segments'
        vert_coords=params.struct_coords;
        [labels] = m_gen_mol_coord_tubules(vert_coords, params);
    case 'mesh'
        mesh_coords=params.struct_coords;
        [labels] = m_gen_mol_coord_mesh(mesh_coords, params);
        
    otherwise
        error(['Unknown sample type: ',num2str(name)]);
end

end
