function [ labels ] = m_gen_mol_coord_mesh( mesh_coords, params )
% This function places the contact point on mesh determined by triangles.
% First determines the number of contact points on each facet (binomial
% distribution, currently with success probability of 1). First places the
% contact points on a parallelogram determined by two of the triangle's
% side, cuts the rectangle into two triangle along one of the diagonals
% (the third side os the tiangle), and if the contact point is located on
% the wrong triangle, mirrors the contact point to the midpoint of the
% diagonal. Eventually connects the linkers to the contact points.

% PARENT: m_gen_mol_coord.m
% CHILDS: m_gen_linker.m, m_gen_linker_rot.m

P=1.0;

% reading parameters for the mesh or the star pattern
if strcmp(params.sample.name,'star')
    dens=params.sample.label_dens*1E-6;
elseif strcmp(params.sample.name,'mesh')
    dens=params.sample.label_dens*1E-6;
else
    disp('Something is wrong in "m_gen_mol_coord_mesh.m".');
end  

N_facet=size(mesh_coords.facet_verts,2);

facet_area=zeros(N_facet,1);
for idx_facet=1:N_facet     % goes through the triangles
    idx_1=mesh_coords.facet_verts(1, idx_facet);
    idx_2=mesh_coords.facet_verts(2, idx_facet);
    idx_3=mesh_coords.facet_verts(3, idx_facet);
    
    vect_1=mesh_coords.vert_coords(:,idx_3)-mesh_coords.vert_coords(:,idx_1);
    vect_2=mesh_coords.vert_coords(:,idx_2)-mesh_coords.vert_coords(:,idx_1);
    facet_area(idx_facet)=norm(cross(vect_1, vect_2)*0.5);
end

N_cont_mean_facet=facet_area.*dens;     % mean number of the contact points on the triangles

N_trials=round(N_cont_mean_facet/P);    % number of trials for the binomial distribution

P_binom=P;   % probability for the binomial distribution

N_cont_facet=zeros(size(N_trials));
for idx_facet=1:size(N_trials,1)
    N_cont_facet(idx_facet,1)=m_gen_random('binomial', N_trials(idx_facet,1), P_binom, 1, 1);       % number of contact points on the triangles
end
%P_binom=repmat(P,length(N_trials),1);   % probability for the binomial distribution
%N_cont_facet=binornd(N_trials,P_binom); % number of contact points on the triangles

N_cont=sum(N_cont_facet);   % total number of contact points

[labels, N_mol_cont, link_vec_sign]=m_gen_linker(N_cont, params, mesh_coords);

idx_cont=0;  % index of the acutal contact point
idx_mol=0;
for idx_facet=1:N_facet
    idx_1=mesh_coords.facet_verts(1, idx_facet);
    idx_2=mesh_coords.facet_verts(2, idx_facet);
    idx_3=mesh_coords.facet_verts(3, idx_facet);
    
    vect_1=mesh_coords.vert_coords(:,idx_3)-mesh_coords.vert_coords(:,idx_1);
    vect_2=mesh_coords.vert_coords(:,idx_2)-mesh_coords.vert_coords(:,idx_1);
    vect_3=vect_2-vect_1;
    diagonal_vect=(vect_1+vect_2); % diagonal vector of the tetragon determined by the 2 vectors of the facet
    % contact point located on one side of this vector are left intact,
    % other located on the other side are reflected center of the tetragon
    
    if isfield(mesh_coords,'norm_vect')
        norm_vect=mesh_coords.norm_vect(:,idx_facet);
    else
        norm_vect=cross(vect_1,vect_2);
    end
    
    
    % polar and azimuth angles of the facet's normal vector
    theta=acos(norm_vect(3)/norm(norm_vect));
    fi=atan(norm_vect(2)/norm_vect(1));
    if isnan(fi)
        fi=0;
    end
    % matrices for rotating the linkers
    R_y=[cos(theta),0,sin(theta);...
        0,1,0;...
        -sin(theta),0,cos(theta)];
    R_z=[cos(fi),-sin(fi),0;...
        sin(fi),cos(fi),0;...
        0,0,1];
    
    for idx_cont_facet=1:N_cont_facet(idx_facet)    % goes through the contact points on the facet
        idx_cont=idx_cont+1;
        cont_vect_facet=rand(1)*vect_1+rand(1)*vect_2;  % placing the contact points in a tetragon
        cont_vect_in_triangle=cont_vect_facet-0.5*diagonal_vect;    % vector pointing to the contact point from the centre on the tetragon
        % if the contact point is located in the wrong triangle determined
        % by the diagonal vector
        if dot(cross(vect_3,cont_vect_in_triangle),cross(vect_3,vect_1))>0
            cont_vect_facet=diagonal_vect-cont_vect_facet;  % reflecting the contact point
        end

        % coordinates of the contact points
        contact_point=cont_vect_facet(:)+mesh_coords.vert_coords(:,idx_1);
        
        % rotating the linkers and connecting them to the contact points
        [labels, idx_mol]=m_gen_linker_rot(params, labels, link_vec_sign, R_y, R_z,  N_mol_cont(idx_cont), idx_mol, contact_point);
        
        labels.init_cont_coords(:,idx_cont)=contact_point; % variable containing contact point coordinates in 3XN_cont array
    end
end
end

