function [ contact_points_seg, N_cont_seg, seg_length ] = m_gen_mol_coord_segments( vert_coords, params, P)
% This function places the initial contact points in uniform distribution
% the curved lines consisting of segments
% ReturnS an array contaning the coordinates of the initial contact points
% ("contact_points_seg"), a list containing arrays storing the number of
% contact points on the segments of each line ("N_cont_seg"), a list
% containing arrays storing the length of the segments of each line
% ("seg_length").

% PARENT: m_gen_mol_coord_tubules.m
% CHILDS: -

% VARIABLES
% offset: applied offset to place the center of the structure into the center of image
% idx_curve: index of the actual curved line
% idx_seg: index of the actual segment on the actual curved line
% dens: densities of the contact points on the different lines
% N_of_vert: number of vertices (plus the starting and ending point) on the actual curved line
% seg_length{idx_curve}: length of the actual curved line in nm
% N_cont_mean_seg: the mean number of contact points on the segments
% N_trials
% p_binom
% N_cont_seg
% N_cont
% contact_points_seg
% idx_cont
% vect
% base
% contact_point
% N_cont_seg: number of contact points on each segment of each line
% seg_length: length of each segment of each line

%if strcmp(params.sample.name,'lines')
%    for idx_curve=1:length(vert_coords)     % goes through the lines
%        dens{idx_curve}=params.sample.label_dens(1,idx_curve)*1E-3;   % density of contact points on the line, rewrite it into a list
%    end
%elseif strcmp(params.sample.name,'segments')
%    dens{1}=params.sample.label_dens*1E-3;
%else
%end  

if strcmp(params.sample.name,'lines')
    for idx_curve=1:length(vert_coords)     % goes through the lines
        dens{idx_curve}=params.sample.label_dens(1,idx_curve)*1E-3;   % density of contact points on the line, rewrite it into a list
    end
elseif strcmp(params.sample.name,'segments')
    for idx_curve=1:length(vert_coords)     % goes through the lines
        dens{idx_curve}=params.sample.label_dens*1E-3;   % density of contact points on the line, rewrite it into a list
    end
else
end 


% Calculating the length of each segment of each curved line and writing
% the densities into a list
for idx_curve=1:length(vert_coords)     % goes through the curved lines
    N_of_vert=length(vert_coords{idx_curve}(1,:));  % number of vertices on the curved line
    seg_length{idx_curve}=zeros(N_of_vert-1,1);     % memory allocation
    for idx_seg=1:N_of_vert-1       % goes through the segments on the actual curve
        seg_length{idx_curve}(idx_seg)=norm((vert_coords{idx_curve}(:,idx_seg+1)-vert_coords{idx_curve}(:,idx_seg)));   %length of the actual segment
    end
end


% 
N_cont_mean_seg=cellfun(@(x,y) x.*y,seg_length,dens,'UniformOutput',false);
% Number of trials needed to place the given mean number of contact points
% on the segments with the given probability
N_trials=cellfun(@(x) round(x./P),N_cont_mean_seg,'UniformOutput',false);
% is this needed fot thr binornd() function?
p_binom={length(N_trials)};

for i=1:length(N_trials)
    p_binom{i}=repmat(P,length(N_trials{i}),1);
end

% number of contact points on the segments according to the binomial
% distribution
N_of_curve=length(seg_length);
N_cont_seg=cell(N_of_curve,1);
for idx_curve=1:N_of_curve     % goes through the curved lines
    N_of_seg=length(seg_length{idx_curve});  % number of vertices on the curved lin
    for idx_seg=1:N_of_seg
        N_cont_seg{idx_curve}(idx_seg)=m_gen_random('binomial',N_trials{idx_curve}(idx_seg),p_binom{idx_curve}(idx_seg),1,1);
    end
end
%N_cont_seg=cellfun(@(x,y) m_gen_random('binomial',x,y,1,1),N_trials,p_binom,'UniformOutput',false);
%N_cont_seg=cellfun(@(x,y) binornd(x,y),N_trials,p_binom,'UniformOutput',false);

% total number of contact points
N_cont=sum(cell2mat(cellfun(@(x) sum(x),N_cont_seg,'UniformOutput',false)));

contact_points_seg=zeros(3,N_cont);    % array for storing the coordinates of the individual contact points

idx_cont=0;

% calculating the contact points on each segments of each curve
for idx_curve=1:length(seg_length)
    for idx_seg=1:length(seg_length{idx_curve})
        vect=vert_coords{idx_curve}(:,idx_seg+1)-vert_coords{idx_curve}(:,idx_seg);
        base=vert_coords{idx_curve}(:,idx_seg);
        for k=1:N_cont_seg{idx_curve}(idx_seg)
            idx_cont=idx_cont+1;
            contact_point=base+vect*rand(1);
            contact_points_seg(:,idx_cont)=contact_point;
        end
    end
end




end

