function [pattern_coords]=m_gen_struct(varargin)
% This function calls the function that calculates the coordinates
% describing the appropriate (the actual structure which needs to be
% calculated) kind of structure. These coordinates can be contained in
% arrays in cell or arrays in struct or simply just in an array depending
% on the pattern. The output variable contins these coordinates.

% PARENT: m_gen_calc_struct_coords.m
% CHILDS:   m_gen_struct_star
%           m_gen_struct_lattice
%           m_gen_struct_lines
%           m_gen_struct_octagons
%           m_gen_struct_vesicles
%           m_gen_struct_rods
%           m_gen_struct_axons
%           m_gen_struct_disks
%           m_gen_read_snake
%           m_gen_read_stl

switch length(varargin)
    case 1
        params = varargin{1};   % struct containing the actual pattern's parameters
    otherwise
        error('Invalid input.')
end

name=params.sample.name;       % name of the actual pattern

if ~ischar(name)
    error('Invalid input.')
end

switch name
    case 'star'
        [pattern_coords] = m_gen_struct_star(params);
    case 'lattice'
        [pattern_coords] = m_gen_struct_lattice(params);
    case 'lines'
        [pattern_coords] = m_gen_struct_lines(params);
    case 'octagons'
        [pattern_coords] = m_gen_struct_octagons(params);
    case 'vesicles'
        [pattern_coords] = m_gen_struct_vesicles(params);
    case 'rods'
        [pattern_coords] = m_gen_struct_rods(params);
    case 'axons'
        [pattern_coords] = m_gen_struct_axons(params);
    case 'disks'
        [pattern_coords] = m_gen_struct_disks(params);
    case 'segments'
        [pattern_coords]=m_gen_read_snake(params);
    case 'mesh'
        [pattern_coords]=m_gen_read_stl(params);
        
    otherwise
        error(['Unknown sample type: ',num2str(name)]);
end
end


