function [ vert_coords ] = m_gen_struct_axons( params )
% This functions calculates the starting and ending point of three axons
% similarily to in case of lines. Coordinates belonging to the individual
% axons are placed in different cell elements. It goues through the axons
% abd calculats "x", "y" and "z" coordinates of their starting and ending
% points. These coordinates are placed in 3x2 array.

% PARENT: m_gen_struct.m
% CHILDS: -

% VARIABLES

% length_axon: size of lines pattern in nm
% fi: polar angles between axons ang the "z" axis
% theta: azimuth angle of axons
% z_0: "z" position axons' centers
% length_axon: size of lines pattern in nm
% idx_axon: index of the actual axon
% x: variables containing the "x" coordinates if the axon's starting and ending points
% y: variables containing the "y" coordinates if the axon's starting and ending points
% z: variables containing the "z" coordinates if the axon's starting and ending points
% vert_point: variable containing the actual axon's starting and ending coordinates in 3x2 array
% vert_coords: cell containing coordinates of starting and ending points

theta=params.sample.axon_theta*pi/180;    % polar angles between axons ang the "z" axis
fi=params.sample.axon_fi*pi/180; % azimuth angle of axons
x_0=params.sample.axon_x; % "x" position axons' centers
y_0=params.sample.axon_y; % "y" position axons' centers
z_0=params.sample.axon_z; % "z" position axons' centers
length_axon=params.sample.axon_length; % size of lines pattern in nm

N_axon=size(length_axon,2);

vert_coords=cell(1,N_axon);  % coordinates of starting and ending points

% calculate molecule positions
for idx_axon=1:N_axon
    % memory allocation and initialization
    vert_coords{idx_axon}=zeros(3,2);
    x=x_0(idx_axon)+[-sin(theta(idx_axon))*cos(fi(idx_axon)),sin(theta(idx_axon))*cos(fi(idx_axon))]*length_axon(idx_axon)/2;
    y=y_0(idx_axon)+[-sin(theta(idx_axon))*sin(fi(idx_axon)),sin(theta(idx_axon))*sin(fi(idx_axon))]*length_axon(idx_axon)/2;
    z=z_0(idx_axon)+[-cos(theta(idx_axon)),cos(theta(idx_axon))]*length_axon(idx_axon)/2;
    vert_point=[x;y;z]; % coordinates of starting and ending points of the actual axon
    vert_coords{idx_axon}=vert_point;   % cell array containing the coordinates
      
end

end

