function [ vert_coords]=m_gen_struct_lines(params)
% This pattern consist of contact points placed along 5 lines. The position
% of the lines are predefined in the "x" and the "y" dimensions, the initial
% "z" position and least angle that the "x-y" plane and the line forms can
% be adjusted for each line seperately. The contact points are randomly
% distributed (in "m_gen_mol_coord_segments.m") on the lines with the same
% density.

% PARENT: m_gen_struct.m
% CHILDS: -

% VARIABLES
% dim: size of the pattern in "x" and "y" dimensions
% dist: distance between the diagonal (4. and 5.) lines in "x" and "y" directions
% a: angles in z of each lines
% z: intial z position of each lines
% idx_lines: indix of the lines to which the actual dye molecule belong to
% vert_point: starting and ending point coordinates of the actual line
% vert_coords: starting and ending point coordinates of the lines

dim=params.sample.lines_dim;%size of lines pattern in nm

dist=params.sample.lines_dist*sqrt(2)/dim; %distance between two diagonal lines
a=params.sample.lines_alpha*pi/180; %angles in z of each lines
z=params.sample.lines_z; %intial z position of each lines

vert_coords=cell(5,1);
% calculate molecule positions
for idx_lines=1:5
    % memory allocation and initialization
    vert_coords{idx_lines}=zeros(3,2);
    %get index of line where the actual molecule is located
    %coordinates of contact points on different lines, at first normal
    %coordinates are being used, then transformation
    switch(idx_lines)
        case 1
            x=[0.,0.25]-0.5;
            y=2*(x+0.5)+0.5-0.5;
            x=x*dim;
            y=y*dim;
            vert_point=[x;y;z(idx_lines)+sqrt(x.^2+(y-0.5*dim).^2)*tan(a(idx_lines))];
        case 2
            x=[0.,1.0]-0.5;
            y=(x+0.5)-0.5;
            x=x*dim;
            y=y*dim;
            vert_point=[x;y;z(idx_lines)+sqrt((x).^2+(y).^2)*tan(a(idx_lines))];
 
        case 3
            x=[0.5,1.0]-0.5;
            y=0.5*((x+0.5)-0.5)-0.5;
            x=x*dim;
            y=y*dim;
            vert_point=[x;y;z(idx_lines)+sqrt((x-0.5*dim).^2+y.^2)*tan(a(idx_lines))];

        case 4
            x=[0.,1]-0.5;
            y=1-(x+0.5)-0.5;
            x=x*dim;
            y=y*dim;
            vert_point=[x;y;z(idx_lines)+sqrt(x.^2+(y-1*dim).^2)*tan(a(idx_lines))];

        case 5
            x=[0,1-dist]-0.5;
            y=1-(x+0.5)-dist-0.5;
            x=x*dim;
            y=y*dim;
            vert_point=[x;y;z(idx_lines)+sqrt(x.^2+(y-(1-dist)*dim).^2)*tan(a(idx_lines))];
    end              
    
    vert_coords{idx_lines}=vert_point;
      
end
end