global m_gen_path
output_dir=[m_gen_path,filesep,'images'];

% output_file_name=[output_dir,filesep,'test.raw'];
output_file_name2=[output_dir,filesep,'test_star.tif'];

tic
rng('default')

% Sample parameter settings
seq_params=[];


seq_params.sample.name='star';
seq_params.sample.star_params=ones(16,1)*400; % N of molecules in the given arm
seq_params.sample.star_dim=30*160; % arm dimension in nm
seq_params.sample.star_offset=(64*160-seq_params.sample.star_dim*2)/2; %offset in nm
seq_params.sample.star_z=0; %plane of pattern
seq_params.sample.link_rad=2; % radius of the linker in nm


% tic
% molecule_pos=m_gen_mol_coord(seq_params.sample.name,seq_params.sample,1);
% toc

% Dye parameter settings
seq_params.dye.name='base_dye';
seq_params.dye.tauon=0.05;
seq_params.dye.tauoff=25;
seq_params.dye.taub=500;
seq_params.dye.lambda=647;
seq_params.dye.N_ofphotonpersec=400000;

% Acqusition / Camera settings
seq_params.aq.frame_size=64;% The frame size NxN.
seq_params.aq.frame_N=2000;% The number of frames.
seq_params.aq.frame_rate=20;% frame/s
seq_params.aq.frame_fill_factor=1;% the fraction of the exposure time used to collect photons.
seq_params.aq.pixel_size=160;
seq_params.aq.bg_level=200;
seq_params.psf.name='gauss';
seq_params.psf.size=220;
seq_params.psf.n=1.33;

traj_t_max=seq_params.aq.frame_N/seq_params.aq.frame_rate;


%%
tic
molecule_pos=m_gen_mol_coord(...
    seq_params.sample.name,...
    seq_params.sample,...
    1);
toc
trajs=m_gen_traj_gen(...
    seq_params.dye.name,...
    traj_t_max,...
    molecule_pos,...
    seq_params.dye,...
    1);
toc
seq=m_gen_trajs_to_seq(...
    trajs,...
    seq_params.aq,...
    seq_params.psf,...
    seq_params.dye);
toc
seq_n=m_gen_noise_addition(...
    seq,...
    seq_params.aq);
toc
% m_gen_seq_save(seq_n,output_file_name);
% toc
m_gen_seq_save(seq_n,output_file_name2);
toc
%%
temp_init=[molecule_pos.init_pos];

figure
scatter3(temp_init(1,:),...
    temp_init(2,:),...
    temp_init(3,:),'.')

set(gca,'DataAspectRatio',[1 1 1])
%%
figure
for qwe=1:length(seq)
    maxI=max([seq(qwe).frame(:);1]);
    imagesc(seq(qwe).frame,[0,maxI])
    axis equal; axis off
    title(num2str(qwe))
    drawnow
    pause(0.03);
    colormap gray
end


