function [ d_image, psf_pos_rem, idx_pix, idx_psf_sampling ] = m_gen_PSF_image_sampling_points( pos, psf_range, N_pixel, pixel_size, sampling_number )
%function [  ] = m_gen_PSF_image_sampling_points(  )
% This function determines the coordinates of sampling points on image
% plane in one dimension at once. The image plane is divided into
% rectangles of equal size and the sampling points can beplaced on the
% center center of these rectangles (pixel_sampling_fill_bool=false) or on
% their vertices (pixel_sampling_fill_bool=true). Area of individual pixels
% can only be divided into whole number of rectangles. First the distance
% of two adjacent sampling points are determined, then the center of the
% sampled area, eventually determines the indices of affected pixels and
% which sampling point to which pixel belongs.


%pos=0*1E-9;
%psf_range=300*1E-9;
%N_pixel=64;
%pixel_size=160*1E-9;
%sampling_number=256;


pixel_sampling_fill_bool=false;

% maximal and minimal coordinates of the affected area in a
% coordiante system shifted to a pixel vertice
% affected area: chosen rectangle in which the PSF is placed
if mod(N_pixel,2)       % if "N_pixel" is odd number
    pixel_rem=pixel_size/2;     % the coordiante system's origo is in the center of a pixel
else                    % if "N_pixel" is even number
    pixel_rem=0;                % the coordiante system's origo is between of at least two pixels
end

border_max=pos+psf_range-pixel_rem;     % coordinate of the affected area's upper border in the shifted coordinate system
border_min=pos-psf_range-pixel_rem;     % coordinate of the affected area's upper border in the shifted coordinate system

% getting initial value of index for determining how many part a pixel should be divided for the PSF sampling
if pixel_sampling_fill_bool
    idx_psf_area=ceil((sampling_number-1)/N_pixel);
elseif ~pixel_sampling_fill_bool
    idx_psf_area=ceil((sampling_number)/N_pixel);
end

if pixel_sampling_fill_bool
    while true
        d_image=pixel_size/idx_psf_area; % distance of the PSF sampling points in the direction

        % number of minimal sampled points in the image plain that includes the affected area
        psf_points=ceil(border_max/d_image)-floor(border_min/d_image)+1;
        if psf_points>sampling_number
            pixel_division=idx_psf_area-1;
            d_image=pixel_size/pixel_division;     % the previous while loop's value
            if rem(N_pixel,2)==1 && rem(pixel_division,2)==1
                sampling_origo_mismatch_bool=true;
            elseif rem(N_pixel,2)==0 || (rem(N_pixel,2)==1 && rem(pixel_division,2)==0)
                sampling_origo_mismatch_bool=false;
            else
               error('Something is wrong during the sampling point calculation.') 
            end
            break;
        end
        idx_psf_area=idx_psf_area+1;
    end
elseif ~pixel_sampling_fill_bool
    while true
        d_image=pixel_size/idx_psf_area; % distance of the PSF sampling points in the direction

        % number of minimal sampled points in the image plain that includes the affected area
        psf_points=ceil(border_max/d_image)-floor(border_min/d_image);
        if psf_points>sampling_number
            pixel_division=idx_psf_area-1;
            d_image=pixel_size/pixel_division;     % the previous while loop's value
            if rem(N_pixel,2)==0 || (rem(N_pixel,2)==1 && rem(pixel_division,2)==0)
                sampling_origo_mismatch_bool=true;
            elseif rem(N_pixel,2)==1 && rem(pixel_division,2)==1
                sampling_origo_mismatch_bool=false;
            else
               error('Something is wrong during the sampling point calculation.') 
            end
            break;
        end
        idx_psf_area=idx_psf_area+1;
    end
end

% determining the center of the sampled area
psf_sampling_shift=xor(sampling_origo_mismatch_bool,rem(sampling_number+1,2))*d_image*0.5;    % "0" or "d_image/2" whether the distance between the PSF area's center and the origo is whole or half whole times the "d_image" 
psf_area_center=round((pos-psf_sampling_shift)/d_image)*d_image+psf_sampling_shift; % coordinate of the PSF area's center
psf_pos_rem=pos-psf_area_center;    % part of the difference between the molecule position and the PSF area's center

sampled_area_min=psf_area_center-(sampling_number-1)*d_image/2;    % coordinate of the PFS area's first sampling point
sampled_area_max=psf_area_center+(sampling_number-1)*d_image/2;    % coordinate of the PFS area's last sampling point

idx_pix_min=max(ceil((sampled_area_min+N_pixel*pixel_size/2)/pixel_size), 1);     % the minimal index of the pixels in the PSF's area
idx_pix_max=min(ceil((sampled_area_max+N_pixel*pixel_size/2)/pixel_size), N_pixel);     % the maximal index of the pixels in the PSF's area

if idx_pix_min>N_pixel || idx_pix_max<1     % if the molecule's PSf is out of the active area
    idx_psf_sampling={};
    idx_pix=[];     % setting void the variable storing the affected pixel indices 
    return          % stop execution and return to the parent function
elseif idx_pix_min>idx_pix_max      % to avoid infinite loop in case of unpredicted error
    error('Error during indexing affected pixels.')
end

if pixel_sampling_fill_bool
    N_cut_sampling_points=abs(min(round((sampled_area_min+N_pixel*pixel_size/2)/d_image),0))+1;
elseif ~pixel_sampling_fill_bool
    N_cut_sampling_points=abs(min(round((sampled_area_min+N_pixel*pixel_size/2+d_image/2)/d_image),0))+1;
end

idx_psf_sampling_min=N_cut_sampling_points+1; % the minimal index of the PSF's sampled points in the actual pixel
idx_psf_sampling_max=idx_psf_sampling_min; % the maximal index of the PSF's sampled points in the actual pixel

idx_pix_loc=1;          % local index of the actual pixel
idx_pix_temp=idx_pix_min;       % index of the actual pixel

if pixel_sampling_fill_bool
    while true
        idx_psf_sampling_max=round((min(idx_pix_temp*pixel_size-N_pixel*pixel_size/2,sampled_area_max)-sampled_area_min)/d_image)+1;  % maximal index of sampling points belonging to the actual pixel

        idx_psf_sampling{idx_pix_loc}=int16(idx_psf_sampling_min:idx_psf_sampling_max);    %indices of the PSF's sampled points in the actual pixel

        idx_psf_sampling_min=idx_psf_sampling_max;  % minimal index of sampling points belonging to the next pixel

        % braking out of the loop at the last pixel affected by the PSF
        if idx_pix_temp==idx_pix_max
           break; 
        end

        % pixel indices for the next loop
        idx_pix_loc=idx_pix_loc+1;                  % local index of the next pixel
        idx_pix_temp=idx_pix_temp+1;            % index of the next pixel
    end
elseif ~pixel_sampling_fill_bool
    while true
        idx_psf_sampling_max=round((min(idx_pix_temp*pixel_size-N_pixel*pixel_size/2-d_image/2,sampled_area_max)-sampled_area_min)/d_image)+1;  % maximal index of sampling points belonging to the actual pixel
        
        idx_psf_sampling{idx_pix_loc}=int16(idx_psf_sampling_min:idx_psf_sampling_max);    %indices of the PSF's sampled points in the actual pixel

        idx_psf_sampling_min=idx_psf_sampling_max+1;  % minimal index of sampling points belonging to the next pixel
        
        % braking out of the loop at the last pixel affected by the PSF
        if idx_pix_temp==idx_pix_max
           break; 
        end

        % pixel indices for the next loop
        idx_pix_loc=idx_pix_loc+1;                  % local index of the next pixel
        idx_pix_temp=idx_pix_temp+1;            % index of the next pixel
    end
end
idx_pix=idx_pix_min:idx_pix_max;  % indices of the affected pixels

%idx_psf_sampling{:}
%psf_area_center
end

